==> razorqt-0.5.1.tar.bz2: razorqt-0.5.1/razorqt-panel/plugin-clock/translations/clock_el_GR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el_GR" version="2.0">
<context>
    <name>RazorClockConfiguration</name>
    <message>
        <source>Razor Clock Settings</source>
        <translation>Ρυθμίσεις ρολογιού Razor</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Ώρα</translation>
    </message>
    <message>
        <source>&amp;Show seconds</source>
        <translation>Εμ&amp;φάνιση δευτερολέπτων</translation>
    </message>
    <message>
        <source>12 &amp;hour style</source>
        <translation>12 &amp;ωρη μορφή</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation>&amp;Γραμματοσειρά</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Γραμματοσειρά</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Ημερομηνία</translation>
    </message>
    <message>
        <source>Show &amp;date</source>
        <translation>Εμφάνιση &amp;ημερομηνίας</translation>
    </message>
    <message>
        <source>D&amp;ate format</source>
        <translation>Μορφή η&amp;μερομηνίας</translation>
    </message>
    <message>
        <source>Fon&amp;t</source>
        <translation>Γρ&amp;αμματοσειρά</translation>
    </message>
    <message>
        <source>Show date in &amp;new line</source>
        <translation>Εμφάνιση ημερομηνίας σε &amp;νέα γραμμή</translation>
    </message>
    <message>
        <source>&amp;Use theme fonts</source>
        <translation>Χρήση γραμματοσειρών &amp;θέματος</translation>
    </message>
    <message>
        <source>Time font</source>
        <translation>Γραμματοσειρά ώρας</translation>
    </message>
    <message>
        <source>Date font</source>
        <translation>Γραμματοσειρά ημερομηνίας</translation>
    </message>
    <message>
        <source>Ultra light</source>
        <translation>Υπερβολικά ελαφρύ</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Ελαφρύ</translation>
    </message>
    <message>
        <source>Ultra black</source>
        <translation>Υπερβολικά μαύρο</translation>
    </message>
    <message>
        <source>Black</source>
        <translation>Μαύρο</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Έντονο</translation>
    </message>
    <message>
        <source>Demi bold</source>
        <translation>Ελαφρώς έντονο</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Πλάγια</translation>
    </message>
</context>
</TS>

==> razorqt-0.5.2.tar.bz2: razorqt-0.5.2/razorqt-panel/plugin-clock/translations/clock_el_GR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el_GR" version="2.0">
<context>
    <name>RazorClockConfiguration</name>
    <message>
        <source>Razor Clock Settings</source>
        <translation>Ρυθμίσεις ρολογιού Razor</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Ώρα</translation>
    </message>
    <message>
        <source>&amp;Show seconds</source>
        <translation>Εμ&amp;φάνιση δευτερολέπτων</translation>
    </message>
    <message>
        <source>12 &amp;hour style</source>
        <translation>12 &amp;ωρη μορφή</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation>&amp;Γραμματοσειρά</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Γραμματοσειρά</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Ημερομηνία</translation>
    </message>
    <message>
        <source>Show &amp;date</source>
        <translation>Εμφάνιση &amp;ημερομηνίας</translation>
    </message>
    <message>
        <source>D&amp;ate format</source>
        <translation>Μορφή η&amp;μερομηνίας</translation>
    </message>
    <message>
        <source>Fon&amp;t</source>
        <translation>Γραμματο&amp;σειρά</translation>
    </message>
    <message>
        <source>Show date in &amp;new line</source>
        <translation>Εμφάνιση ημερομηνίας σε &amp;νέα γραμμή</translation>
    </message>
    <message>
        <source>&amp;Use theme fonts</source>
        <translation>Χρήση γραμματοσειρών &amp;θέματος</translation>
    </message>
    <message>
        <source>Time font</source>
        <translation>Γραμματοσειρά ώρας</translation>
    </message>
    <message>
        <source>Date font</source>
        <translation>Γραμματοσειρά ημερομηνίας</translation>
    </message>
    <message>
        <source>Ultra light</source>
        <translation>Υπερβολικά ελαφρύ</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Ελαφρύ</translation>
    </message>
    <message>
        <source>Ultra black</source>
        <translation>Υπερβολικά μαύρο</translation>
    </message>
    <message>
        <source>Black</source>
        <translation>Μαύρο</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Έντονο</translation>
    </message>
    <message>
        <source>Demi bold</source>
        <translation>Ελαφρώς έντονο</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Πλάγια</translation>
    </message>
</context>
</TS>
